{% extends 'core_main_app/_render/admin/theme/tools/modal.html' %}

{% block modal_id %}file-preview-modal{% endblock %}
{% block modal_title %}File preview{% endblock %}

{% block modal_body %}
    <div id="fileImageDisplayArea"></div>
    <pre id="fileTextDisplayArea"></pre>
    <div class="alert alert-info alert-preview" id="errorArea"></div>
{% endblock %}

{% block modal_footer %}
    <div class="float-right">
        <a id="btn-file-preview-download"
           class="btn btn-primary"
           href="#">
            <i class="fa fa-download"></i>
            Download
        </a>
    </div>
{% endblock %}

